==> base-runtimes-0.1.6.tgz: package/README.md <==
# base-runtimes [![NPM version](https://img.shields.io/npm/v/base-runtimes.svg?style=flat)](https://www.npmjs.com/package/base-runtimes) [![NPM downloads](https://img.shields.io/npm/dm/base-runtimes.svg?style=flat)](https://npmjs.org/package/base-runtimes) [![Build Status](https://img.shields.io/travis/node-base/base-runtimes.svg?style=flat)](https://travis-ci.org/node-base/base-runtimes)

> Plugin for adding composer-runtimes to base applications, complementing the base-tasks and base-generators plugins.

You might also be interested in [base-task](https://github.com/node-base/base-task).

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install base-runtimes --save
```

This plugin is a basic wrapper for [composer-runtimes](https://github.com/doowb/composer-runtimes) and [composer](https://github.com/doowb/composer), see those libraries to learn more about available features and options, or to report issues related to runtimes colors or formatting.

## Usage

```js
var runtimes = require('base-runtimes');
var task = require('base-tasks');
var Base = require('base');
var app = new Base();

// register plugins
app.use(task());
app.use(runtimes());

app.task('default', function(cb) {
  cb();
});

// run the `default` task
app.build(function(err) {
  if (err) throw err;
});
```

With `runtimes` registed, you should see something like the following when `.build` is called:

<img width="363" alt="output generated after adding base-runtimes plugin for composer-runtimes" src="https://cloud.githubusercontent.com/assets/383994/12613017/d2efca0c-c4c4-11e5-90ae-e140227cfab6.png">

## Related projects

You might also be interested in these projects:

* [base-fs](https://www.npmjs.com/package/base-fs): base-methods plugin that adds vinyl-fs methods to your 'base' application for working with the file… [more](https://www.npmjs.com/package/base-fs) | [homepage](https://github.com/node-base/base-fs)
* [base-generators](https://www.npmjs.com/package/base-generators): Adds project-generator support to your `base` application. | [homepage](https://github.com/node-base/base-generators)
* [base-pipeline](https://www.npmjs.com/package/base-pipeline): base-methods plugin that adds pipeline and plugin methods for dynamically composing streaming plugin pipelines. | [homepage](https://github.com/node-base/base-pipeline)
* [base-plugins](https://www.npmjs.com/package/base-plugins): Upgrade's plugin support in base applications to allow plugins to be called any time after… [more](https://www.npmjs.com/package/base-plugins) | [homepage](https://github.com/node-base/base-plugins)
* [base-task](https://www.npmjs.com/package/base-task): base plugin that provides a very thin wrapper around [https://github.com/doowb/composer](https://github.com/doowb/composer) for adding task methods to… [more](https://www.npmjs.com/package/base-task) | [homepage](https://github.com/node-base/base-task)
* [base](https://www.npmjs.com/package/base): base is the foundation for creating modular, unit testable and highly pluggable node.js applications, starting… [more](https://www.npmjs.com/package/base) | [homepage](https://github.com/node-base/base)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/base-runtimes/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/node-base/base-runtimes/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on April 20, 2016._

==> base-runtimes-0.1.9.tgz: package/README.md <==
# base-runtimes [![NPM version](https://img.shields.io/npm/v/base-runtimes.svg?style=flat)](https://www.npmjs.com/package/base-runtimes) [![NPM downloads](https://img.shields.io/npm/dm/base-runtimes.svg?style=flat)](https://npmjs.org/package/base-runtimes) [![Build Status](https://img.shields.io/travis/node-base/base-runtimes.svg?style=flat)](https://travis-ci.org/node-base/base-runtimes)

Plugin for adding composer-runtimes to base applications, complementing the base-tasks and base-generators plugins.

You might also be interested in [base-task](https://github.com/node-base/base-task).

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install base-runtimes --save
```

This plugin is a basic wrapper for [composer-runtimes](https://github.com/doowb/composer-runtimes) and [composer](https://github.com/doowb/composer), see those libraries to learn more about available features and options, or to report issues related to runtimes colors or formatting.

## Usage

```js
var runtimes = require('base-runtimes');
var task = require('base-tasks');
var Base = require('base');
var app = new Base();

// register plugins
app.use(task());
app.use(runtimes());

app.task('default', function(cb) {
  cb();
});

// run the `default` task
app.build(function(err) {
  if (err) throw err;
});
```

With `runtimes` registed, you should see something like the following when `.build` is called:

<img width="363" alt="output generated after adding base-runtimes plugin for composer-runtimes" src="https://cloud.githubusercontent.com/assets/383994/12613017/d2efca0c-c4c4-11e5-90ae-e140227cfab6.png">

## Related projects

You might also be interested in these projects:

* [base-fs](https://www.npmjs.com/package/base-fs): base-methods plugin that adds vinyl-fs methods to your 'base' application for working with the file… [more](https://www.npmjs.com/package/base-fs) | [homepage](https://github.com/node-base/base-fs)
* [base-generators](https://www.npmjs.com/package/base-generators): Adds project-generator support to your `base` application. | [homepage](https://github.com/node-base/base-generators)
* [base-pipeline](https://www.npmjs.com/package/base-pipeline): base-methods plugin that adds pipeline and plugin methods for dynamically composing streaming plugin pipelines. | [homepage](https://github.com/node-base/base-pipeline)
* [base-plugins](https://www.npmjs.com/package/base-plugins): Upgrade's plugin support in base applications to allow plugins to be called any time after… [more](https://www.npmjs.com/package/base-plugins) | [homepage](https://github.com/node-base/base-plugins)
* [base-task](https://www.npmjs.com/package/base-task): base plugin that provides a very thin wrapper around [https://github.com/doowb/composer](https://github.com/doowb/composer) for adding task methods to… [more](https://www.npmjs.com/package/base-task) | [homepage](https://github.com/node-base/base-task)
* [base](https://www.npmjs.com/package/base): base is the foundation for creating modular, unit testable and highly pluggable node.js applications, starting… [more](https://www.npmjs.com/package/base) | [homepage](https://github.com/node-base/base)

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/node-base/base-runtimes/issues/new).

## Building docs

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install verb && npm run docs
```

Or, if [verb](https://github.com/verbose/verb) is installed globally:

```sh
$ verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/node-base/base-runtimes/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on April 27, 2016._
